Aurinko.Types.Pagination (Aurinko v0.2.1)

Copy Markdown View Source

Represents a paginated API response with delta sync tokens.

Summary

Functions

Parse a raw Aurinko paged response body into a Pagination struct.

Types

t()

@type t() :: %Aurinko.Types.Pagination{
  next_delta_token: String.t() | nil,
  next_page_token: String.t() | nil,
  records: [map()],
  total_size: integer() | nil
}

Functions

from_response(body)

@spec from_response(map()) :: t()

Parse a raw Aurinko paged response body into a Pagination struct.