Represents a paginated API response with delta sync tokens.
Summary
Functions
Parse a raw Aurinko paged response body into a Pagination struct.
Represents a paginated API response with delta sync tokens.
Parse a raw Aurinko paged response body into a Pagination struct.